==> beast-privilege-api-3.0.2-GS-20250807.080953-17-sources.jar: com/thebeastshop/privilege/vo/FlowerPackageCardVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class FlowerPackageCardVO implements Serializable {
    private Long packageId;
    private Integer cardType;
    private Integer quantity;
    private String cardTypeText;
    private String cardFrom;
    private String cardTo;
    private String cardContent;

    public Long getPackageId() {
        return packageId;
    }

    public void setPackageId(Long packageId) {
        this.packageId = packageId;
    }

    public Integer getCardType() {
        return cardType;
    }

    public void setCardType(Integer cardType) {
        this.cardType = cardType;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public String getCardTypeText() {
        return cardTypeText;
    }

    public void setCardTypeText(String cardTypeText) {
        this.cardTypeText = cardTypeText;
    }

    public String getCardFrom() {
        return cardFrom;
    }

    public void setCardFrom(String cardFrom) {
        this.cardFrom = cardFrom;
    }

    public String getCardTo() {
        return cardTo;
    }

    public void setCardTo(String cardTo) {
        this.cardTo = cardTo;
    }

    public String getCardContent() {
        return cardContent;
    }

    public void setCardContent(String cardContent) {
        this.cardContent = cardContent;
    }
}

==> beast-privilege-api-3.0.14-GS-20251021.073259-1-sources.jar: com/thebeastshop/privilege/vo/FlowerPackageCardVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class FlowerPackageCardVO implements Serializable {

    private Integer cardId;
    private Long packageId;
    private Integer cardType;
    private Integer quantity;
    private String cardTypeText;
    private String cardFrom;
    private String cardTo;
    private String cardContent;

    public Integer getCardId() {
        return cardId;
    }

    public void setCardId(Integer cardId) {
        this.cardId = cardId;
    }
    public Long getPackageId() {
        return packageId;
    }

    public void setPackageId(Long packageId) {
        this.packageId = packageId;
    }

    public Integer getCardType() {
        return cardType;
    }

    public void setCardType(Integer cardType) {
        this.cardType = cardType;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public String getCardTypeText() {
        return cardTypeText;
    }

    public void setCardTypeText(String cardTypeText) {
        this.cardTypeText = cardTypeText;
    }

    public String getCardFrom() {
        return cardFrom;
    }

    public void setCardFrom(String cardFrom) {
        this.cardFrom = cardFrom;
    }

    public String getCardTo() {
        return cardTo;
    }

    public void setCardTo(String cardTo) {
        this.cardTo = cardTo;
    }

    public String getCardContent() {
        return cardContent;
    }

    public void setCardContent(String cardContent) {
        this.cardContent = cardContent;
    }
}
